summaryrefslogtreecommitdiff
path: root/Tools/Source/FrameworkTasks
diff options
context:
space:
mode:
authorjwang36 <jwang36@6f19259b-4bc3-4df7-8a09-765794883524>2006-08-09 02:25:52 +0000
committerjwang36 <jwang36@6f19259b-4bc3-4df7-8a09-765794883524>2006-08-09 02:25:52 +0000
commitcaf9538f28de46e9ab3712611688e5353402183d (patch)
tree65474729c1f3dcc4d8941fd91bc95e1331c64b28 /Tools/Source/FrameworkTasks
parent8a9783c1f3f75ec5cd6e869f812e62fb5bcf1406 (diff)
downloadedk2-platforms-caf9538f28de46e9ab3712611688e5353402183d.tar.xz
Changed the alignment related member and method to conform to FFS spec.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@1220 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'Tools/Source/FrameworkTasks')
-rw-r--r--Tools/Source/FrameworkTasks/org/tianocore/framework/tasks/GenFfsFileTask.java16
1 files changed, 8 insertions, 8 deletions
diff --git a/Tools/Source/FrameworkTasks/org/tianocore/framework/tasks/GenFfsFileTask.java b/Tools/Source/FrameworkTasks/org/tianocore/framework/tasks/GenFfsFileTask.java
index 1500fdff66..8e0fb4ab72 100644
--- a/Tools/Source/FrameworkTasks/org/tianocore/framework/tasks/GenFfsFileTask.java
+++ b/Tools/Source/FrameworkTasks/org/tianocore/framework/tasks/GenFfsFileTask.java
@@ -85,11 +85,11 @@ public class GenFfsFileTask extends Task implements EfiDefine, FfsTypes {
///
boolean ffsAttribRecovery = false;
///
/// ffsAligenment value is used to set the corresponding bit in the output
/// FFS file header.The specified FFS alignment must be a value between 0
/// and 7 inclusive
///
- int ffsAlignment = 0;
+ int ffsAttribDataAlignment = 0;
///
/// ffsAttribChecksum value is used to set the corresponding bit in the
/// output FFS file header
@@ -490,8 +490,8 @@ public class GenFfsFileTask extends Task implements EfiDefine, FfsTypes {
This function is to get the ffsAligment
@return The value of ffsAligment.
**/
- public int getFfsAlignment() {
- return this.ffsAlignment;
+ public int getFfsAttribDataAlignment() {
+ return this.ffsAttribDataAlignment;
}
/**
@@ -500,12 +500,12 @@ public class GenFfsFileTask extends Task implements EfiDefine, FfsTypes {
This function is to set ffsAligment
@param ffsAligment The value of ffsAligment.
**/
- public void setFfsAlignment(int ffsAligment) {
- this.ffsAlignment = ffsAligment;
- if (this.ffsAlignment > 7) {
+ public void setFfsAttribDataAlignment(int ffsAligment) {
+ this.ffsAttribDataAlignment = ffsAligment;
+ if (this.ffsAttribDataAlignment > 7) {
throw new BuildException ("FFS_ALIGMENT Scope is 0-7");
} else {
- attributes |= (((byte)this.ffsAlignment) << 3);
+ attributes |= (((byte)this.ffsAttribDataAlignment) << 3);
}
}
@@ -85,11 +85,11 @@ public class GenFfsFileTask extends Task implements EfiDefine, FfsTypes {
boolean ffsAttribRecovery = false;
///
- /// ffsAligenment value is used to set the corresponding bit in the output
+ /// ffsAttribDataAlignment value is used to set the corresponding bit in the output
/// FFS file header.The specified FFS alignment must be a value between 0
/// and 7 inclusive